==> haskell-resource-pool-0.2.3.2-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-E3OCiqwe137Er9aRv4slPP
key: resource-pool-0.2.3.2-E3OCiqwe137Er9aRv4slPP
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Pool
abi: 6572b29584633cc8000c33f2d4ef86a6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/resource-pool-0.2.3.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-E3OCiqwe137Er9aRv4slPP
depends:
    base-4.9.0.0 hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg time-1.6.0.1
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resource-pool-0.2.3.2-11-i686.pkg.tar.xz: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-3moP3n1CqLz53yrpIJMjdi
key: resource-pool-0.2.3.2-3moP3n1CqLz53yrpIJMjdi
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Pool
abi: 0cdb1dcb973255e3a30238bb7f17e8a7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/resource-pool-0.2.3.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-3moP3n1CqLz53yrpIJMjdi
depends:
    base-4.9.0.0 hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg time-1.6.0.1
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
